Gemeinde Adressverwaltung GUI: Gemeinde.dialogGemeindeAuswahl Klassenreferenz

Gemeinde Adressverwaltung GUI

Öffentliche Methoden | Öffentliche Attribute | Aufstellung aller Elemente
Gemeinde.dialogGemeindeAuswahl Klassenreferenz
Klassendiagramm für Gemeinde.dialogGemeindeAuswahl:
[Legende]
Zusammengehörigkeiten von Gemeinde.dialogGemeindeAuswahl:
[Legende]

## Öffentliche Methoden
def | __init__ (self, parent, auswahl=[])
def | handleOK (self)

## Öffentliche Attribute
| parent
| lblTitel
| frmChoices
| frmButtons
| btnQuit
| btnGo

Die Dokumentation für diese Klasse wurde erzeugt aufgrund der Datei:

- Gemeinde.py